# OpenBB Biztoc Provider

This extension integrates the Biztoc data provider
into the OpenBB Platform.

## Installation

To install the extension, run the following command in this folder:

```bash
pip install openbb-biztoc
```

Documentation available [here](https://docs.openbb.co/platform/development/contributing).
